@@ -510,7 +510,7 @@ def makemask(mask,A,savefile=None):
     fig.mydata['mode']=None
     fig.mydata['mask']=mask.astype('bool')
     fig.mydata['redrawneeded']=True
-    conn_id=fig.canvas.mpl_connect('button_press_event',clickevent)
+    fig.canvas.mpl_connect('button_press_event',clickevent)
     fig.toexit=False
     fig.show()
     firstdraw=1;
@@ -540,7 +540,7 @@ def makemask(mask,A,savefile=None):
     return mask
     
 
-def basicfittinggui(data,title='',blocking=False):
+def basicfittinggui_old(data,title='',blocking=False):
     """Graphical user interface to carry out basic (Guinier, Porod) fitting
     to 1D scattering data.
     
@@ -607,16 +607,17 @@ def basicfittinggui(data,title='',blocking=False):
     ax=pylab.axes((leftborder,topborder-(len(buttons)+len(plots))*(0.8)/(len(buttons)+len(plots)),leftbox_end,0.7/(len(buttons)+len(plots))*len(plots) ))
     pylab.title('Plot types')
     rb=matplotlib.widgets.RadioButtons(ax,plots,active=7)
-    if blocking:
+    pylab.gcf().blocking=blocking
+    if pylab.gcf().blocking:
         ax=pylab.axes((leftborder,0.03,leftbox_end,bottomborder-0.03))
         b=matplotlib.widgets.Button(ax,"Done")
         fig=pylab.gcf()
         fig.fittingdone=False
-        def onclick(A=None,B=None,fig=fig):
+        def onclick1(A=None,B=None,fig=fig):
             fig.fittingdone=True
-            blocking=False
+            pylab.gcf().blocking=False
      #       print "blocking should now end"
-        b.on_clicked(onclick)
+        b.on_clicked(onclick1)
     pylab.axes((0.4,bottomborder,0.5,0.8))
     def onselectplottype(plottype,q=data['q'],I=data['Intensity'],title=title):
         pylab.cla()
@@ -680,6 +681,107 @@ def basicfittinggui(data,title='',blocking=False):
     #print "returning"
     return listoffits
         
+def basicfittinggui(data,title='',blocking=False):
+    """Graphical user interface to carry out basic (Guinier, Porod) fitting
+    to 1D scattering data.
+    
+    Inputs:
+        data: 1D dataset
+        title: title to display
+        blocking: False if the function should return just after drawing the
+            fitting gui. True if it should wait for closing the figure window.
+    Output:
+        If blocking was False then none, this leaves a figure open for further
+            user interactions.
+        If blocking was True then after the window was destroyed, a list of
+            the fits and their parameters are returned.
+    """
+    
+    if not isinstance(data,utils.SASDict):
+        return basicfittinggui_old(data,title,blocking)
+        
+    
+    listoffits=[]
+    
+    leftborder=0.05
+    topborder=0.9
+    bottomborder=0.1
+    leftbox_end=0.3
+    fig=pylab.figure()
+    pylab.clf()
+    plots=[{'name':'Guinier','transform':utils.SASTransformGuinier(),
+            'plotmethod':'plot'},
+           {'name':'Guinier thickness','transform':utils.SASTransformGuinier(2),
+            'plotmethod':'plot'},
+           {'name':'Guinier cross-section','transform':utils.SASTransformGuinier(1),
+            'plotmethod':'plot'},
+           {'name':'Porod','transform':utils.SASTransformPorod(2),
+            'plotmethod':'plot'},
+           {'name':'Double linear','transform':utils.SASTransformLogLog(False,False),
+            'plotmethod':'plot'},
+           {'name':'Logarithmic y','transform':utils.SASTransformLogLog(False,False),
+            'plotmethod':'semilogy'},
+           {'name':'Logarithmic x','transform':utils.SASTransformLogLog(False,False),
+            'plotmethod':'semilogx'},
+           {'name':'Double logarithmic','transform':utils.SASTransformLogLog(False,False),
+            'plotmethod':'loglog'}]
+    buttons=[{'name':'Guinier','fitmethod':'guinierfit'},
+             {'name':'Guinier thickness','fitmethod':'guinierthicknessfit'},
+             {'name':'Guinier cross-section','fitmethod':'guiniercrosssectionfit'},
+             {'name':'Porod','fitmethod':'porodfit'},
+             {'name':'A * q^B','fitmethod':'powerlawfit'},
+             {'name':'A * q^B + C','fitmethod':'powerlawconstantbackgroundfit'},
+             {'name':'A * q^B + C + D * q','fitmethod':'powerlawlinearbackgroundfit'}]
+            
+    for i in range(len(buttons)):
+        ax=pylab.axes((leftborder,topborder-(i+1)*(0.8)/(len(buttons)+len(plots)),leftbox_end,0.7/(len(buttons)+len(plots))))
+        but=matplotlib.widgets.Button(ax,buttons[i]['name'])
+        def onclick(A=None,B=None,data=data,type=buttons[i]['name'],fitfun=buttons[i]['fitmethod']):
+            data1=data.trimzoomed()
+            data1.transform=data.transform
+            pylab.figure()
+            res=getattr(data1,fitfun).__call__(plot=True)
+            listoffits.append({'type':type,'res':res,'time':time.time(),'qmin':data1.q.min(),'qmax':data1.q.max()})
+            pylab.gcf().show()
+        but.on_clicked(onclick)
+    ax=pylab.axes((leftborder,topborder-(len(buttons)+len(plots))*(0.8)/(len(buttons)+len(plots)),leftbox_end,0.7/(len(buttons)+len(plots))*len(plots) ))
+    pylab.title('Plot types')
+    rb=matplotlib.widgets.RadioButtons(ax,[p['name'] for p in plots],active=7)
+    pylab.gcf().blocking=blocking
+    if pylab.gcf().blocking: #if blocking mode is desired, put a "Done" button.
+        ax=pylab.axes((leftborder,0.03,leftbox_end,bottomborder-0.03))
+        b=matplotlib.widgets.Button(ax,"Done")
+        fig=pylab.gcf()
+        fig.fittingdone=False
+        def onclick1(A=None,B=None,fig=fig):
+            fig.fittingdone=True
+            pylab.gcf().blocking=False
+     #       print "blocking should now end"
+        b.on_clicked(onclick1)
+    pylab.axes((0.45,bottomborder,0.5,0.8))
+    def onselectplottype(plottype,q=data['q'],I=data['Intensity'],title=title):
+        pylab.cla()
+        plotinfo=[d for d in plots if d['name']==plottype][0]
+        data.transform=plotinfo['transform']
+        getattr(data,plotinfo['plotmethod']).__call__()
+        pylab.title(title)
+        pylab.gcf().show()
+    rb.on_clicked(onselectplottype)
+    pylab.title(title)
+    data.loglog('.')
+    pylab.gcf().show()
+    pylab.draw()
+    fig=pylab.gcf()
+    while blocking:
+        fig.waitforbuttonpress()
+#        print "buttonpress"
+        if fig.fittingdone:
+            blocking=False
+            #print "exiting"
+    #print "returning"
+    return listoffits
+
+
 #data quality tools
 def testsmoothing(x,y,smoothing=1e-5,slidermin=1e-6,slidermax=1e-2):
     ax=pylab.axes((0.2,0.85,0.7,0.05));
@@ -810,9 +912,6 @@ def assesstransmission(fsns,titleofsample,mode='Gabriel',dirs=[]):
     axisBcY=pylab.gcf().add_axes([hborder,1-vborder-3*axisheight-2*vspacing,axiswidth,axisheight])
     axisDORIS=pylab.gcf().add_axes([hborder,1-vborder-4*axisheight-3*vspacing,axiswidth,axisheight])
 
-    doris=[h['Current1'] for h in header]
-    orix=[h['BeamPosX'] for h in params]
-    oriy=[h['BeamPosY'] for h in params]
     print "Assesstransmission"
     for l in range(len(energies)):
         print "  Energy: ",energies[l]
@@ -919,7 +1018,6 @@ def findpeak(xdata,ydata,prompt=None,mode='Lorentz',scaling='lin',blind=False,re
         res=scipy.optimize.leastsq(gausscostfun,p0,args=(x1,y1),maxfev=10000,full_output=True)
         p1=res[0]
         cov=res[1]
-        ier=res[4]
         if not blind:
             if scaling=='log':
                 pylab.semilogy(x1,p1[3]+p1[0]/(np.sqrt(2*np.pi)*p1[1])*np.exp(-(x1-p1[2])**2/(2*p1[1]**2)),'r-')
@@ -934,7 +1032,6 @@ def findpeak(xdata,ydata,prompt=None,mode='Lorentz',scaling='lin',blind=False,re
         res=scipy.optimize.leastsq(lorentzcostfun,p0,args=(x1,y1),maxfev=10000,full_output=True)
         p1=res[0]
         cov=res[1]
-        ier=res[4]
         if not blind:
             if scaling=='log':
                 pylab.semilogy(x1,p1[3]+p1[0]*utils.lorentzian(p1[2],p1[1],x1),'r-')
